@@ -7,7 +7,7 @@ import time
 optionsfile = "/etc/pearlupdate-automatic-upgrades.conf"
 logfile = "/var/log/pearlupdate.log"
 log = open(logfile, "a")
-log.write(f"\n-- Automatic Upgrade starting {time.strftime('%a %d %b %Y %H:%M:%S %Z')}:\n")
+log.write("\n-- Automatic Upgrade starting %s:\n" % time.strftime('%a %d %b %Y %H:%M:%S %Z'))
 log.flush()
 
 pkla_source = "/usr/share/pearllinux/pearlupdate/automation/99-pearlupdate-temporary.pkla"
